"use client";
import Link from "next/link";
import { useEffect, useState } from "react";
import { account } from "@/lib/appwrite";

export default function Dashboard() {
    const [user, setUser] = useState(null);

    useEffect(() => {
        const getUser = async () => {
            try {
                const response = await account.get();
                setUser(response);
            } catch (error) {
                window.location.href = "/login";
            }
        };
        getUser();
    }, []);

    const handleSignOut = async () => {
        try {
            await account.deleteSession("current");
            window.location.href = "/login";
        } catch (error) {
            alert("Error signing out: " + error.message);
        }
    };

    return (
        <div className="flex flex-col items-center justify-center min-h-screen bg-gray-100 dark:bg-gray-900 text-black dark:text-white">
            <h1 className="text-xl font-bold">Welcome to Dashboard</h1>
            <Link href="/dashboard/crud">
                <button className="bg-blue-500 dark:bg-blue-700 text-white px-4 py-2 mt-4 rounded">
                    Go to CRUD Page
                </button>
            </Link>
            {user ? (
                <>
                    <h1 className="text-xl font-bold mt-4">
                        Welcome, {user.name || user.email || "User"}
                    </h1>
                    <button
                        className="bg-red-500 dark:bg-red-700 text-white px-4 py-2 mt-4 rounded"
                        onClick={handleSignOut}
                    >
                        Sign Out
                    </button>
                </>
            ) : (
                <h1 className="mt-4">Loading....</h1>            
            )}
        </div>
    );
}
