"use client";
import { useState, useEffect } from "react";
import { useRouter } from "next/navigation";
import { account, ID } from "../../lib/appwrite";

export default function Auth() {
    const [email, setEmail] = useState("");
    const [password, setPassword] = useState("");
    const [isLogin, setIsLogin] = useState(true);
    const [loading, setLoading] = useState(true); //  Manage loading state
    const router = useRouter();

    useEffect(() => {
        const checkUserSession = async () => {
            try {
                await account.get(); //  If logged in, redirect to dashboard
                router.push("/dashboard");
            } catch (error) {
                console.log("No active session, stay on login page.");
            } finally {
                setLoading(false); //  Stop loading after session check
            }
        };
        checkUserSession();
    }, []);

    const handleAuth = async (e) => {
        e.preventDefault();
        try {
            if (isLogin) {
                await account.createEmailPasswordSession(email, password);
                alert("Login successful!");
            } else {
                await account.create(ID.unique(), email, password);
                alert("Signup successful! You can now log in.");
                setIsLogin(true);
                return;
            }
            router.push("/dashboard");
        } catch (error) {
            alert(error.message);
            console.error("Auth error:", error);
        }
    };

    //  Show a message while checking authentication instead of a blank page
    if (loading) {
        return (
            <div className="flex flex-col items-center justify-center min-h-screen">
                {/* <p className="text-lg font-semibold">Loading</p> */}
            </div>
        );
    }

    return (
        <div className="flex flex-col items-center justify-center min-h-screen">
            <h2 className="text-xl font-bold">{isLogin ? "Login" : "Sign Up"}</h2>
            <form onSubmit={handleAuth} className="flex flex-col gap-4 mt-4">
                <input
                    type="email"
                    placeholder="Email"
                    className="border p-2"
                    value={email}
                    onChange={(e) => setEmail(e.target.value)}
                    required
                />
                <input
                    type="password"
                    placeholder="Password"
                    className="border p-2"
                    value={password}
                    onChange={(e) => setPassword(e.target.value)}
                    required
                />
                <button type="submit" className="bg-blue-500 text-white p-2">
                    {isLogin ? "Login" : "Sign Up"}
                </button>
            </form>
            <p className="mt-2 text-sm">
                {isLogin ? "Don't have an account?" : "Already have an account?"}{" "}
                <button className="text-blue-500 underline" onClick={() => setIsLogin(!isLogin)}>
                    {isLogin ? "Sign Up" : "Login"}
                </button>
            </p>
        </div>
    );
}
